0.9.9 API documentation: ext.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

ext.hpp
Go to the documentation of this file.
1
5 #include "detail/setup.hpp"
6
7 #pragma once
8
9 #include "glm.hpp"
10
11 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_MESSAGE_EXT_INCLUDED_DISPLAYED)
12 # define GLM_MESSAGE_EXT_INCLUDED_DISPLAYED
13 # pragma message("GLM: All extensions included (not recommended)")
14 #endif//GLM_MESSAGES
15
16 #include "./ext/matrix_double2x2.hpp"
17 #include "./ext/matrix_double2x2_precision.hpp"
18 #include "./ext/matrix_double2x3.hpp"
19 #include "./ext/matrix_double2x3_precision.hpp"
20 #include "./ext/matrix_double2x4.hpp"
21 #include "./ext/matrix_double2x4_precision.hpp"
22 #include "./ext/matrix_double3x2.hpp"
23 #include "./ext/matrix_double3x2_precision.hpp"
24 #include "./ext/matrix_double3x3.hpp"
25 #include "./ext/matrix_double3x3_precision.hpp"
26 #include "./ext/matrix_double3x4.hpp"
27 #include "./ext/matrix_double3x4_precision.hpp"
28 #include "./ext/matrix_double4x2.hpp"
29 #include "./ext/matrix_double4x2_precision.hpp"
30 #include "./ext/matrix_double4x3.hpp"
31 #include "./ext/matrix_double4x3_precision.hpp"
32 #include "./ext/matrix_double4x4.hpp"
33 #include "./ext/matrix_double4x4_precision.hpp"
34
35 #include "./ext/matrix_float2x2.hpp"
36 #include "./ext/matrix_float2x2_precision.hpp"
37 #include "./ext/matrix_float2x3.hpp"
38 #include "./ext/matrix_float2x3_precision.hpp"
39 #include "./ext/matrix_float2x4.hpp"
40 #include "./ext/matrix_float2x4_precision.hpp"
41 #include "./ext/matrix_float3x2.hpp"
42 #include "./ext/matrix_float3x2_precision.hpp"
43 #include "./ext/matrix_float3x3.hpp"
44 #include "./ext/matrix_float3x3_precision.hpp"
45 #include "./ext/matrix_float3x4.hpp"
46 #include "./ext/matrix_float3x4_precision.hpp"
47 #include "./ext/matrix_float4x2.hpp"
48 #include "./ext/matrix_float4x2_precision.hpp"
49 #include "./ext/matrix_float4x3.hpp"
50 #include "./ext/matrix_float4x3_precision.hpp"
51 #include "./ext/matrix_float4x4.hpp"
52 #include "./ext/matrix_float4x4_precision.hpp"
53
54 #include "./ext/matrix_relational.hpp"
55
56 #include "./ext/quaternion_double.hpp"
57 #include "./ext/quaternion_double_precision.hpp"
58 #include "./ext/quaternion_float.hpp"
59 #include "./ext/quaternion_float_precision.hpp"
60 #include "./ext/quaternion_geometric.hpp"
61 #include "./ext/quaternion_relational.hpp"
62
63 #include "./ext/scalar_constants.hpp"
64 #include "./ext/scalar_int_sized.hpp"
65 #include "./ext/scalar_relational.hpp"
66
67 #include "./ext/vector_bool1.hpp"
68 #include "./ext/vector_bool1_precision.hpp"
69 #include "./ext/vector_bool2.hpp"
70 #include "./ext/vector_bool2_precision.hpp"
71 #include "./ext/vector_bool3.hpp"
72 #include "./ext/vector_bool3_precision.hpp"
73 #include "./ext/vector_bool4.hpp"
74 #include "./ext/vector_bool4_precision.hpp"
75
76 #include "./ext/vector_double1.hpp"
77 #include "./ext/vector_double1_precision.hpp"
78 #include "./ext/vector_double2.hpp"
79 #include "./ext/vector_double2_precision.hpp"
80 #include "./ext/vector_double3.hpp"
81 #include "./ext/vector_double3_precision.hpp"
82 #include "./ext/vector_double4.hpp"
83 #include "./ext/vector_double4_precision.hpp"
84
85 #include "./ext/vector_float1.hpp"
86 #include "./ext/vector_float1_precision.hpp"
87 #include "./ext/vector_float2.hpp"
88 #include "./ext/vector_float2_precision.hpp"
89 #include "./ext/vector_float3.hpp"
90 #include "./ext/vector_float3_precision.hpp"
91 #include "./ext/vector_float4.hpp"
92 #include "./ext/vector_float4_precision.hpp"
93
94 #include "./ext/vector_int1.hpp"
95 #include "./ext/vector_int1_precision.hpp"
96 #include "./ext/vector_int2.hpp"
97 #include "./ext/vector_int2_precision.hpp"
98 #include "./ext/vector_int3.hpp"
99 #include "./ext/vector_int3_precision.hpp"
100 #include "./ext/vector_int4.hpp"
101 #include "./ext/vector_int4_precision.hpp"
102
103 #include "./ext/vector_relational.hpp"
104
105 #include "./ext/vector_uint1.hpp"
106 #include "./ext/vector_uint1_precision.hpp"
107 #include "./ext/vector_uint2.hpp"
108 #include "./ext/vector_uint2_precision.hpp"
109 #include "./ext/vector_uint3.hpp"
110 #include "./ext/vector_uint3_precision.hpp"
111 #include "./ext/vector_uint4.hpp"
112 #include "./ext/vector_uint4_precision.hpp"
113
114 #include "./gtc/bitfield.hpp"
115 #include "./gtc/color_space.hpp"
116 #include "./gtc/constants.hpp"
117 #include "./gtc/epsilon.hpp"
118 #include "./gtc/integer.hpp"
119 #include "./gtc/matrix_access.hpp"
120 #include "./gtc/matrix_integer.hpp"
121 #include "./gtc/matrix_inverse.hpp"
122 #include "./gtc/matrix_transform.hpp"
123 #include "./gtc/noise.hpp"
124 #include "./gtc/packing.hpp"
125 #include "./gtc/quaternion.hpp"
126 #include "./gtc/random.hpp"
127 #include "./gtc/reciprocal.hpp"
128 #include "./gtc/round.hpp"
129 #include "./gtc/type_precision.hpp"
130 #include "./gtc/type_ptr.hpp"
131 #include "./gtc/ulp.hpp"
132 #include "./gtc/vec1.hpp"
133 #if GLM_CONFIG_ALIGNED_GENTYPES == GLM_ENABLE
134 # include "./gtc/type_aligned.hpp"
135 #endif
136
137 #ifdef GLM_ENABLE_EXPERIMENTAL
138 #include "./gtx/associated_min_max.hpp"
139 #include "./gtx/bit.hpp"
140 #include "./gtx/closest_point.hpp"
141 #include "./gtx/color_encoding.hpp"
142 #include "./gtx/color_space.hpp"
143 #include "./gtx/color_space_YCoCg.hpp"
144 #include "./gtx/compatibility.hpp"
145 #include "./gtx/component_wise.hpp"
146 #include "./gtx/dual_quaternion.hpp"
147 #include "./gtx/euler_angles.hpp"
148 #include "./gtx/extend.hpp"
149 #include "./gtx/extended_min_max.hpp"
150 #include "./gtx/fast_exponential.hpp"
151 #include "./gtx/fast_square_root.hpp"
152 #include "./gtx/fast_trigonometry.hpp"
153 #include "./gtx/functions.hpp"
154 #include "./gtx/gradient_paint.hpp"
155 #include "./gtx/handed_coordinate_space.hpp"
156 #include "./gtx/integer.hpp"
157 #include "./gtx/intersect.hpp"
158 #include "./gtx/log_base.hpp"
159 #include "./gtx/matrix_cross_product.hpp"
160 #include "./gtx/matrix_interpolation.hpp"
161 #include "./gtx/matrix_major_storage.hpp"
162 #include "./gtx/matrix_operation.hpp"
163 #include "./gtx/matrix_query.hpp"
164 #include "./gtx/mixed_product.hpp"
165 #include "./gtx/norm.hpp"
166 #include "./gtx/normal.hpp"
167 #include "./gtx/normalize_dot.hpp"
168 #include "./gtx/number_precision.hpp"
169 #include "./gtx/optimum_pow.hpp"
170 #include "./gtx/orthonormalize.hpp"
171 #include "./gtx/perpendicular.hpp"
172 #include "./gtx/polar_coordinates.hpp"
173 #include "./gtx/projection.hpp"
174 #include "./gtx/quaternion.hpp"
175 #include "./gtx/raw_data.hpp"
176 #include "./gtx/rotate_vector.hpp"
177 #include "./gtx/spline.hpp"
178 #include "./gtx/std_based_type.hpp"
179 #if !(GLM_COMPILER & GLM_COMPILER_CUDA)
180 # include "./gtx/string_cast.hpp"
181 #endif
182 #include "./gtx/transform.hpp"
183 #include "./gtx/transform2.hpp"
184 #include "./gtx/vec_swizzle.hpp"
185 #include "./gtx/vector_angle.hpp"
186 #include "./gtx/vector_query.hpp"
187 #include "./gtx/wrap.hpp"
188
189 #if GLM_HAS_TEMPLATE_ALIASES
190 # include "./gtx/scalar_multiplication.hpp"
191 #endif
192
193 #if GLM_HAS_RANGE_FOR
194 # include "./gtx/range.hpp"
195 #endif
196 #endif//GLM_ENABLE_EXPERIMENTAL
epsilon.hpp
GLM_GTC_epsilon
vector_relational.hpp
GLM_EXT_vector_relational
dual_quaternion.hpp
GLM_GTX_dual_quaternion
polar_coordinates.hpp
GLM_GTX_polar_coordinates
closest_point.hpp
GLM_GTX_closest_point
vector_float3.hpp
Core features
matrix_float3x4_precision.hpp
Core features
matrix_double2x4_precision.hpp
Core features
handed_coordinate_space.hpp
GLM_GTX_handed_coordinate_space
vector_bool3.hpp
Core features
raw_data.hpp
GLM_GTX_raw_data
matrix_float3x3_precision.hpp
Core features
vector_bool2.hpp
Core features
string_cast.hpp
GLM_GTX_string_cast
vector_uint1_precision.hpp
GLM_EXT_vector_uint1_precision
intersect.hpp
GLM_GTX_intersect
vector_int1_precision.hpp
GLM_EXT_vector_int1_precision
normalize_dot.hpp
GLM_GTX_normalize_dot
integer.hpp
GLM_GTX_integer
rotate_vector.hpp
GLM_GTX_rotate_vector
vector_double3_precision.hpp
Core features
matrix_major_storage.hpp
GLM_GTX_matrix_major_storage
vector_uint3.hpp
Core features
vector_double2_precision.hpp
Core features
matrix_float3x2.hpp
Core features
matrix_interpolation.hpp
GLM_GTX_matrix_interpolation
vector_angle.hpp
GLM_GTX_vector_angle
transform2.hpp
GLM_GTX_transform2
matrix_double4x2_precision.hpp
Core features
matrix_double2x2_precision.hpp
Core features
wrap.hpp
GLM_GTX_wrap
vector_query.hpp
GLM_GTX_vector_query
projection.hpp
GLM_GTX_projection
constants.hpp
GLM_GTC_constants
vector_int4_precision.hpp
Core features
perpendicular.hpp
GLM_GTX_perpendicular
matrix_double4x4.hpp
Core features
matrix_float4x3.hpp
Core features
matrix_double2x4.hpp
Core features
vector_bool4_precision.hpp
Core features
matrix_float2x3.hpp
Core features
std_based_type.hpp
GLM_GTX_std_based_type
matrix_float2x2.hpp
Core features
component_wise.hpp
GLM_GTX_component_wise
ulp.hpp
GLM_GTC_ulp
round.hpp
GLM_GTC_round
vector_int3.hpp
Core features
orthonormalize.hpp
GLM_GTX_orthonormalize
matrix_double3x2_precision.hpp
Core features
integer.hpp
GLM_GTC_integer
vector_float1.hpp
GLM_EXT_vector_float1
matrix_float4x4_precision.hpp
Core features
matrix_query.hpp
GLM_GTX_matrix_query
vector_double1_precision.hpp
GLM_EXT_vector_double1_precision
matrix_float2x4_precision.hpp
Core features
vec_swizzle.hpp
GLM_GTX_vec_swizzle
matrix_double4x2.hpp
Core features
type_ptr.hpp
GLM_GTC_type_ptr
matrix_double2x2.hpp
Core features
gradient_paint.hpp
GLM_GTX_gradient_paint
bitfield.hpp
GLM_GTC_bitfield
range.hpp
GLM_GTX_range
vector_float2_precision.hpp
Core features
matrix_float3x3.hpp
Core features
matrix_transform.hpp
GLM_GTC_matrix_transform
matrix_cross_product.hpp
GLM_GTX_matrix_cross_product
vector_bool1_precision.hpp
GLM_EXT_vector_bool1_precision
type_aligned.hpp
GLM_GTC_type_aligned
vector_uint1.hpp
GLM_EXT_vector_uint1
quaternion.hpp
GLM_GTX_quaternion
color_space_YCoCg.hpp
GLM_GTX_color_space_YCoCg
vector_int1.hpp
GLM_EXT_vector_int1
normal.hpp
GLM_GTX_normal
color_space.hpp
GLM_GTC_color_space
vector_float4.hpp
Core features
noise.hpp
GLM_GTC_noise
vector_bool4.hpp
Core features
vector_double2.hpp
Core features
matrix_float2x2_precision.hpp
Core features
matrix_integer.hpp
GLM_GTC_matrix_integer
matrix_access.hpp
GLM_GTC_matrix_access
extended_min_max.hpp
GLM_GTX_extented_min_max
vec1.hpp
GLM_GTC_vec1
transform.hpp
GLM_GTX_transform
vector_uint2_precision.hpp
Core features
quaternion_double_precision.hpp
GLM_EXT_quaternion_double_precision
log_base.hpp
GLM_GTX_log_base
compatibility.hpp
GLM_GTX_compatibility
scalar_int_sized.hpp
GLM_EXT_scalar_int_sized
vector_int2_precision.hpp
Core features
optimum_pow.hpp
GLM_GTX_optimum_pow
functions.hpp
GLM_GTX_functions
quaternion_relational.hpp
GLM_EXT_quaternion_relational
vector_double4_precision.hpp
Core features
fast_square_root.hpp
GLM_GTX_fast_square_root
vector_uint4.hpp
Core features
quaternion_float_precision.hpp
GLM_EXT_quaternion_float_precision
vector_int4.hpp
Core features
matrix_double4x3_precision.hpp
Core features
scalar_relational.hpp
GLM_EXT_scalar_relational
matrix_double2x3_precision.hpp
Core features
glm.hpp
Core features
random.hpp
GLM_GTC_random
euler_angles.hpp
GLM_GTX_euler_angles
spline.hpp
GLM_GTX_spline
quaternion.hpp
GLM_GTC_quaternion
color_space.hpp
GLM_GTX_color_space
vector_float4_precision.hpp
Core features
norm.hpp
GLM_GTX_norm
color_encoding.hpp
GLM_GTX_color_encoding
reciprocal.hpp
GLM_GTC_reciprocal
vector_float3_precision.hpp
Core features
matrix_float4x4.hpp
Core features
mixed_product.hpp
GLM_GTX_mixed_producte
matrix_double3x2.hpp
Core features
vector_double1.hpp
GLM_EXT_vector_double1
matrix_float2x4.hpp
Core features
matrix_double3x4_precision.hpp
Core features
type_precision.hpp
GLM_GTC_type_precision
scalar_constants.hpp
GLM_EXT_scalar_constants
matrix_double3x3_precision.hpp
Core features
fast_trigonometry.hpp
GLM_GTX_fast_trigonometry
bit.hpp
GLM_GTX_bit
vector_uint4_precision.hpp
Core features
quaternion_geometric.hpp
GLM_EXT_quaternion_geometric
vector_float2.hpp
Core features
fast_exponential.hpp
GLM_GTX_fast_exponential
vector_uint3_precision.hpp
Core features
quaternion_float.hpp
GLM_EXT_quaternion_float
matrix_float3x2_precision.hpp
Core features
vector_bool1.hpp
GLM_EXT_vector_bool1
matrix_double4x3.hpp
Core features
matrix_float4x2.hpp
Core features
matrix_double2x3.hpp
Core features
vector_bool3_precision.hpp
Core features
matrix_float3x4.hpp
Core features
extend.hpp
GLM_GTX_extend
vector_bool2_precision.hpp
Core features
vector_uint2.hpp
Core features
quaternion_double.hpp
GLM_EXT_quaternion_double
matrix_double4x4_precision.hpp
Core features
vector_int2.hpp
Core features
number_precision.hpp
GLM_GTX_number_precision
vector_double4.hpp
Core features
matrix_float4x3_precision.hpp
Core features
matrix_operation.hpp
GLM_GTX_matrix_operation
vector_double3.hpp
Core features
matrix_float2x3_precision.hpp
Core features
matrix_inverse.hpp
GLM_GTC_matrix_inverse
matrix_double3x4.hpp
Core features
scalar_multiplication.hpp
Experimental extensions
vector_int3_precision.hpp
Core features
packing.hpp
GLM_GTC_packing
matrix_double3x3.hpp
Core features
associated_min_max.hpp
GLM_GTX_associated_min_max
vector_float1_precision.hpp
GLM_EXT_vector_float1_precision
matrix_relational.hpp
GLM_EXT_matrix_relational